@@ -9,14 +9,14 @@ use Encode qw(encode_utf8);
 
 use parent qw(HTTP::Request);
 
-our $VERSION = '1.17';
+our $VERSION = '1.19';
 
 sub new {
     my $class = shift;
     my $options = shift;
     my $self;
 
-    if ($options->{api_type} eq 'oauth') {
+    if (($options->{api_type} || '') eq 'oauth') {
 
         $options->{args}->{request_method}='POST';
         $options->{args}->{request_url}=$options->{rest_uri};
